## **Laboratorio#2**

Universidad del Valle de Guatemala <br>
Facultad de Ingeniería <br>
Departamento de Ciencias de la Computación <br>
CC3085 - Inteligencia Artificial <br>

## Descripcion

**Librería simple que permite la creación de redes bayesianas.** <br>

## Instalación

pip install BayesianNetwork

## Uso

Ver archivo: Ejemplo.py
